/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: _stat64i32
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class _stat64i32 {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int _st_atimeOffset_;
	public static final int _st_ctimeOffset_;
	public static final int _st_devOffset_;
	public static final int _st_gidOffset_;
	public static final int _st_inoOffset_;
	public static final int _st_modeOffset_;
	public static final int _st_mtimeOffset_;
	public static final int _st_nlinkOffset_;
	public static final int _st_rdevOffset_;
	public static final int _st_sizeOffset_;
	public static final int _st_uidOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		_st_atimeOffset_ = 0;
		_st_ctimeOffset_ = 0;
		_st_devOffset_ = 0;
		_st_gidOffset_ = 0;
		_st_inoOffset_ = 0;
		_st_modeOffset_ = 0;
		_st_mtimeOffset_ = 0;
		_st_nlinkOffset_ = 0;
		_st_rdevOffset_ = 0;
		_st_sizeOffset_ = 0;
		_st_uidOffset_ = 0;
	}

}
